RoadInfo class Common

Road information value object.

Simple value object describing a road label used in route and instruction contexts. It packages the human-readable road name together with the shield classification used to select an icon or rendering style for UI displays and signposting.

See also:

Constructors

RoadInfo({required String roadname, required RoadShieldType shieldtype})
Creates a new instance of RoadInfo.

Properties

hashCode int
The hash code for this object.
no setterinherited
roadname String
The human-readable name of the road (for example A1, Main St).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shieldtype RoadShieldType
The road shield classification used to select an icon or style for the road label.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited