PTAlertActivePeriod class Maps & 3D Scenes

Period when a PTAlertInfo is active.

Both bounds are optional: a null start means the alert has been active since forever, a null end means the alert is open-ended.

Also see:

Constructors

PTAlertActivePeriod({DateTime? start, DateTime? end})
Create a PTAlertActivePeriod.

Properties

end DateTime?
UTC end of the period; null means open-ended.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime?
UTC start of the period; null means active since forever.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited