activePeriods property
Periods when the alert is active.
An empty list means the alert is active for as long as the feed carries it.
Implementation
final List<PTAlertActivePeriod> activePeriods;
Periods when the alert is active.
An empty list means the alert is active for as long as the feed carries it.
final List<PTAlertActivePeriod> activePeriods;