PTAlertSeverityLevel enum Maps & 3D Scenes
Severity of a PTAlertInfo (GTFS-RT SeverityLevel enum).
Values outside the GTFS-RT enum are mapped to unknown.
Also see:
- PTAlertInfo.severityLevel — The severity for a specific alert.
Values
- unknown → const PTAlertSeverityLevel
-
Unknown severity.
- info → const PTAlertSeverityLevel
-
Information.
- warning → const PTAlertSeverityLevel
-
Warning.
- severe → const PTAlertSeverityLevel
-
Severe.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PTAlertSeverityLevel> - A constant List of the values in this enum, in order of their declaration.