WatermarkPosition enum Maps & 3D Scenes
Watermark logo placement on the map view.
Controls where the watermark logo is anchored on the rendered map. The chosen position is used together with GemView.setWatermarkLogoProperties.
See also:
- GemView.setWatermarkLogoProperties - Configure the watermark logo.
- GemView.watermarkLogoVisibility - Show or hide the watermark logo.
Values
- left → const WatermarkPosition
-
Watermark on the left side of the screen.
- right → const WatermarkPosition
-
Watermark on the right side of the screen.
- top → const WatermarkPosition
-
Watermark on the top side of the screen.
- bottom → const WatermarkPosition
-
Watermark on the bottom side of the screen.
- center → const WatermarkPosition
-
Watermark in the center of the screen.
- topLeft → const WatermarkPosition
-
Watermark on the top left corner of the screen.
- topRight → const WatermarkPosition
-
Watermark on the top right corner of the screen.
- bottomLeft → const WatermarkPosition
-
Watermark on the bottom left corner of the screen.
- bottomRight → const WatermarkPosition
-
Watermark on the bottom right corner of the screen.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WatermarkPosition> - A constant List of the values in this enum, in order of their declaration.