NavigationInstructionUpdateInfo class
Detailed information about a navigation instruction update.
Provided by the onNavigationInstructionOptimized callback in
NavigationService.startNavigation and NavigationService.startSimulation.
Contains the set of instruction fields that changed since the last update,
enabling efficient UI updates by redrawing only affected components.
See also:
- NavigationService.startNavigation - Register the optimized instruction callback.
- NavigationInstructionDifferenceResult - Enumeration of diffable instruction fields.
- NavigationInstructionUpdateEvents - Events that triggered the update.
Constructors
- Creates a NavigationInstructionUpdateInfo instance.
Properties
-
differences
↔ Set<
NavigationInstructionDifferenceResult> -
The set of instruction fields that differ from the previous instruction.
getter/setter pair
-
events
↔ Set<
NavigationInstructionUpdateEvents> -
The set of events that triggered this instruction update.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNewRoute ↔ bool
-
Whether the update is due to a new route being set (e.g. after recalculation).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited