NavigationInstructionUpdateInfo constructor
NavigationInstructionUpdateInfo({
- required Set<
NavigationInstructionDifferenceResult> differences, - required bool hasNewRoute,
- required Set<
NavigationInstructionUpdateEvents> events,
Creates a NavigationInstructionUpdateInfo instance.
The API users typically do not create NavigationInstructionUpdateInfo instances directly.
Parameters
differences: Set of instruction fields that differ from the previous update.hasNewRoute: Whether the update is due to a new route being set (e.g. after recalculation). When true,differencesis empty because all fields should be considered changed.events: Set of events that triggered this instruction update.
Implementation
NavigationInstructionUpdateInfo({
required this.differences,
required this.hasNewRoute,
required this.events,
});