speedAccuracy property
double
get
speedAccuracy
Accuracy estimate for the speed measurement in meters per second.
Indicates the precision of the speed data. Typical accuracy for consumer GPS devices is approximately 2 m/s under good conditions with steady speed and high position accuracy. Valid speed accuracy values are always positive.
Not available on web: the browser Geolocation API does not report a speed accuracy, so this always returns -1 there.
Returns
- double: Speed accuracy in m/s (positive, or -1 if unavailable)
Implementation
double get speedAccuracy;