EVCarModel class Routing
An electric vehicle car model used for EV route calculations.
Contains vehicle specifications relevant to EV routing such as battery capacity, charging ports, range, efficiency, and fast charge capability. Instances are obtained from RoutingService.getEVCarModels.
Properties
- batteryCapacity → double
-
The usable battery capacity in Wh.
no setter
- efficiency → int
-
The energy consumption in Wh/km.
no setter
- fastCharge → int
-
How many km can be charged in one hour (10-80% interval).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRegisteredAutoReleaseObject ↔ bool
-
getter/setter pairinherited
- id → int
-
The unique identifier of the car model.
no setter
- name → String
-
The name of the car model.
no setter
- pointerId → int
-
The pointer ID of the native object
no setterinherited
- ports → int
-
Supported charging ports, a combination of one or more charging connector types.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- towbarPossible → int
-
The maximum weight available on the vehicle towbar.
no setter
- vehicleRange → int
-
The vehicle range in meters.
no setter
Methods
-
dispose(
) → void -
Disposes the native object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAutoReleaseObject(
int pointerId) → void -
Registers an object for auto release.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited