RouteRestrictionType enum Routing

Route restriction type.

Describes a kind of restriction that applies to a portion of a route, such as access restrictions, transport restrictions or vehicle-attribute restrictions (weight, height, length, width, axle load, plate based).

Values are flag bits and can be combined into a Set. The SDK returns restriction information as a Set<RouteRestrictionType> via TurnDetails.restrictions, NavigationInstruction.currentRestrictions, and RestrictionSection.restrictions.

See also:

Inheritance
Available extensions

Values

transportNotAllowed → const RouteRestrictionType

Route transport mode restriction.

accessRestricted → const RouteRestrictionType

Access restriction (e.g. private road).

avoidPreferences → const RouteRestrictionType

User avoid preferences restriction (e.g. avoid toll road, avoid motorway, etc.).

vehicleWeight → const RouteRestrictionType

Vehicle weight over limit restriction.

vehicleHeight → const RouteRestrictionType

Vehicle height over limit restriction.

vehicleLength → const RouteRestrictionType

Vehicle length over limit restriction.

vehicleWidth → const RouteRestrictionType

Vehicle width over limit restriction.

vehicleAxleLoad → const RouteRestrictionType

Vehicle axle load over limit restriction.

vehiclePlate → const RouteRestrictionType

Vehicle plate restriction.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RouteRestrictionType>
A constant List of the values in this enum, in order of their declaration.