PTAlertCause enum Maps & 3D Scenes
Cause of a PTAlertInfo (GTFS-RT Cause enum).
Values outside the GTFS-RT enum are mapped to unknownCause.
Also see:
- PTAlertInfo.cause — The cause for a specific alert.
Values
- unknownCause → const PTAlertCause
-
Unknown cause.
- otherCause → const PTAlertCause
-
Other cause not represented by any other value.
- technicalProblem → const PTAlertCause
-
Technical problem.
- strike → const PTAlertCause
-
Strike.
- demonstration → const PTAlertCause
-
Demonstration.
- accident → const PTAlertCause
-
Accident.
- holiday → const PTAlertCause
-
Holiday.
- weather → const PTAlertCause
-
Weather.
- maintenance → const PTAlertCause
-
Maintenance.
- construction → const PTAlertCause
-
Construction.
- policeActivity → const PTAlertCause
-
Police activity.
- medicalEmergency → const PTAlertCause
-
Medical emergency.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PTAlertCause> - A constant List of the values in this enum, in order of their declaration.