PTOccupancyStatus enum Maps & 3D Scenes
Occupancy status of a vehicle (GTFS-RT OccupancyStatus enum).
Values above notAcceptingPassengers mean there is no usable crowding data. The scale is NOT strictly linear — display the producer's state, don't interpolate.
Values outside the GTFS-RT enum are mapped to noDataAvailable.
Also see:
- PTCrowdingInfo.occupancyStatus — The occupancy status for specific crowding data.
- PTTrip.departureOccupancyStatus — The predicted occupancy for a departure.
Values
- empty → const PTOccupancyStatus
-
Empty.
- manySeatsAvailable → const PTOccupancyStatus
-
Many seats available.
- fewSeatsAvailable → const PTOccupancyStatus
-
Few seats available.
- standingRoomOnly → const PTOccupancyStatus
-
Standing room only.
- crushedStandingRoomOnly → const PTOccupancyStatus
-
Crushed standing room only.
- full → const PTOccupancyStatus
-
Full.
- notAcceptingPassengers → const PTOccupancyStatus
-
Not accepting passengers.
- noDataAvailable → const PTOccupancyStatus
-
No usable crowding data.
- notBoardable → const PTOccupancyStatus
-
Not boardable (no usable crowding data).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PTOccupancyStatus> - A constant List of the values in this enum, in order of their declaration.